////////////////////////////////////////////////////////////////////////////////
// supermissile
////////////////////////////////////////////////////////////////////////////////
//
// File: SMKeyboard.h
//
// Description: Declaration for functionality of the keyboard routines. Also
//				contains the constant definitions for each key.
//			    Basically a wrapper around SDL functionality.
//
//				See SMKeyboard.cpp
//
////////////////////////////////////////////////////////////////////////////////
#ifndef SMKEYBOARD_H
#define SMKEYBOARD_H

// Valid AlphaNumerics for SMUITextEntry
// 1  - 26
// 57 - 63
// 67, 68, 70
// 82 - 98
// 133 - 134

#define SMK_NONE 0

#define SMK_A	1
#define SMK_B	2
#define SMK_C	3
#define SMK_D	4
#define SMK_E	5
#define SMK_F	6
#define SMK_G	7
#define SMK_H	8
#define SMK_I	9
#define SMK_J	10
#define SMK_K	11
#define SMK_L	12
#define SMK_M	13
#define SMK_N	14
#define SMK_O	15
#define SMK_P	16
#define SMK_Q	17
#define SMK_R	18
#define SMK_S	19
#define SMK_T	20
#define SMK_U	21
#define SMK_V	22
#define SMK_W	23
#define SMK_X	24
#define SMK_Y	25
#define SMK_Z	26

#define SMK_RETURN			53
#define SMK_TAB				54
#define SMK_DELETE			55
#define SMK_BACKSPACE		56
#define SMK_QUOTE			57
#define SMK_COMMA			58
#define SMK_MINUS			59
#define SMK_PERIOD			60
#define SMK_FORWARDSLASH	61
#define SMK_BACKSLASH		62
#define SMK_COLON			63
#define SMK_SEMICOLON		64
#define SMK_OPENPAREN		65
#define SMK_CLOSEPAREN		66
#define SMK_OPENBRACKET		67
#define SMK_CLOSEBRACKET	68
#define SMK_ESCAPE			69
#define SMK_BACKQUOTE		70

#define SMK_0				71
#define SMK_1				72
#define SMK_2				73
#define SMK_3				74
#define SMK_4				75
#define SMK_5				76
#define SMK_6				78
#define SMK_7				79
#define SMK_8				80
#define SMK_9				81

#define SMK_NUM_0			82
#define SMK_NUM_1			83
#define SMK_NUM_2			84
#define SMK_NUM_3			85
#define SMK_NUM_4			86
#define SMK_NUM_5			87
#define SMK_NUM_6			88
#define SMK_NUM_7			89
#define SMK_NUM_8			90
#define SMK_NUM_9			91
#define SMK_NUM_PERIOD		92
#define SMK_NUM_DIVIDE		93
#define SMK_NUM_ASTERISK	94
#define SMK_NUM_MINUS		95
#define SMK_NUM_PLUS		96
#define SMK_NUM_ENTER		97
#define SMK_NUM_EQUALS		98

#define SMK_UP				99
#define SMK_RIGHT			100
#define SMK_LEFT			101
#define SMK_DOWN			102
#define SMK_HOME			103
#define SMK_END				104
#define SMK_PAGEUP			105
#define SMK_PAGEDOWN		106
#define SMK_F1				107
#define SMK_F2				108
#define SMK_F3				109
#define SMK_F4				110
#define SMK_F5				111
#define SMK_F6				112
#define SMK_F7				113
#define SMK_F8				114
#define SMK_F9				115
#define SMK_F10				116
#define SMK_F11				117
#define SMK_F12				118
#define SMK_F13				119
#define SMK_F14				120
#define SMK_F15				121

#define SMK_LSHIFT			122
#define SMK_RSHIFT			123
#define SMK_LALT			124
#define SMK_RALT			125
#define SMK_NUMLOCK			126
#define SMK_CAPSLOCK		127
#define SMK_SCROLLOCK		128
#define SMK_LSUPER			129
#define SMK_RSUPER			130
#define SMK_RMETA			131
#define SMK_LMETA			132

#define SMK_SPACE			133
#define SMK_EQUALS			134

#define SMK_LCTRL			135
#define SMK_RCTRL			136

#define SMK_END_PRIVATE		SMK_RCTRL + 1

int SMKeyPressed();
void SMUnsetKeys();
int SMKey(int);
int SMKey(int, int);
const char *SMKeyToString(int);

void _SMUnsetKey(SDLKey);
void _SMSetKey(SDLKey);
void _SMSetKeyToValue(SDLKey, int);
void _SMInitKeys(void);

extern int _SMKeys[SMK_END_PRIVATE];
extern int _SMKeysDown[SMK_END_PRIVATE];
extern char _SMKeyStrings[][SMK_END_PRIVATE];

#endif
