////////////////////////////////////////////////////////////////////////////////
// supermissile
////////////////////////////////////////////////////////////////////////////////
//
// File: SMTexture.h
//
// Description: Declaration for the texture class. An SMTexture is essentially
//				a wrapper around an OpenGL texture, loaded via SDL. Allows for
//				drawing with a multitude of different modes, depending on how
//				the user would like to draw said texture
//
//				Currently supports BITMAP and PNG formats in both RGB and RGBA
//
//				See SMTexture.cpp
//
////////////////////////////////////////////////////////////////////////////////
#ifndef SMTEXTURE_H
#define SMTEXTURE_H

#include "SMIncludes.h"

extern int _SMTextureMode;
void SMSetTextureMode(int);

class SMTexture
{
private:
	GLuint textureID; // Internal ID for use with openGL
	int _width;
	int _height;
	int loadImage(char *);
	void commonInit();
	GLint _format; // Format the texture was generated with in openGL (RGBA/etc)
	GLvoid *_getPixels;	// Retains the pixel information from a previous getPixel call
	
	friend SMTexture *SMTextureFromScreen(int, int);
	int loadFromData(int w, int h, GLint bytesPerPixel, GLenum textureFormat, char *data);
protected:
public:
	// These are all described in the source file
	SMTexture();
	SMTexture(char *filePath);
	~SMTexture();
	int width();
	int height();
	int w();
	int h();
	void draw(int xPos, int yPos, int doQuadWrap);
	void draw(int xPos, int yPos, float alpha, float scale, int rot, int flipMode, int doQuadWrap);
	void draw(int startX, int startY, int endX, int endY, int xPos, int yPos, int doQuadWrap);
	void draw(int startX, int startY, int endX, int endY, int xPos, int yPos, float alpha, float scale, int rot, int flipMode, int doQuadWrap);
	void draw(int startX, int startY, int endX, int endY, int width, int height, int xPos, int yPos, float alpha, float scale, int rot, int flipMode, int doQuadWrap);
	void bind();
	void drawingPosition(int, int, float, int, int);
	void getPixel(int, int, float &, float &, float &, float &);
	void getPixel(int, int, float &, float &, float &, float &, int);
};

#endif
