////////////////////////////////////////////////////////////////////////////////
// supermissile
////////////////////////////////////////////////////////////////////////////////
//
// File: SMUIDialogBox.h
//
// Description: Declaration of the SMUIDialogBox class. This class renders a
//				dialog box that is a combination of text and a varying amount of
//				buttons.
//
//				See SMUIDialogBox.cpp
//
////////////////////////////////////////////////////////////////////////////////
#ifndef SMUIDIALOGBOX_H
#define SMUIDIALOGBOX_H

#include "SuperMissile.h"

class SMUIDialogBox : public _SMUIWidget
{
private:
	SMFont *_font;
	char *_fontPath;
	int _fontMode;
	char *_message;
	int _lastButtonIndexClicked;
	std::vector <SMUIButton *> *_buttons;
	
	int _padding;
	
	float _bgr;
	float _bgg;
	float _bgb;
	float _bga;
	
	float _tr;
	float _tg;
	float _tb;
	float _ta;
	
	float _bdr;
	float _bdg;
	float _bdb;
	float _bda;
	
	void resize();
	
public:
	
	SMUIDialogBox();
	~SMUIDialogBox();
	
	void setBackgroundColor(float, float, float, float);
	void setTextColor(float, float, float, float);
	void setBorderColor(float, float, float, float);
	
	void setButtonNormalBackgroundColor(float, float, float, float);
	void setButtonDepressedBackgroundColor(float, float, float, float);
	void setButtonBorderColor(float, float, float, float);
	void setButtonTextColor(float, float, float, float);
	
	int setFont(char *, int);
	int setFontSize(int);
	void setMessage(char *);
	void addButton(char *);
	
	void setPadding(int);
	
	void poll();
	void draw();
	
	int buttonIndexClicked();
	
	static const int MAX_MESSAGE_LENGTH = 512;
	
protected:
};

#endif
