////////////////////////////////////////////////////////////////////////////////
// supermissile
////////////////////////////////////////////////////////////////////////////////
//
// File: SMUIFileBrowser.h
//
// Description: Declaration of the SMUIFileBrowser class. This class renders a
//				file browser that is a combination of a listbox containing 
//				contents of a given directory, a text entry widget listing
//				the current path being examined, and button widgets for closing
//				the browser, or accepting/selecting a given file on disk.
//
//				See SMUIFileBrowser.cpp
//
////////////////////////////////////////////////////////////////////////////////
#ifndef SMUIFILEBROWSER_H
#define SMUIFILEBROWSER_H

class SMUIFileBrowser : public _SMUIWidget
{
private:
	SMUITextEntry *_textEntry;
	char *_previousDirectory;
	SMUIButton *_confirmButton;
	SMUIButton *_cancelButton;
	SMUIListBox *_fileList;
	
	SMTimer *_doubleClickTimer;
	int _clicked;
	int _clickedAndReleased;
	int _clickedItemIndex;
	int _padding;
	
	void updateSubWidgets();
	void loadDirectory(char *);
	
	int _bufLen;
	char *_selection;
	
	float _bgr;
	float _bgg;
	float _bgb;
	float _bga;
	float _bdr;
	float _bdg;
	float _bdb;
	float _bda;
	
protected:
public:
	SMUIFileBrowser();
	SMUIFileBrowser(int, char *, int, int, char *, char *);
	~SMUIFileBrowser();
	
	void setFileListRowColors(float, float, float, float, float, float, float, float);
	void setFileListBordercolor(float, float, float, float);
	void setFileListTextColor(float, float, float, float);
	void setFileListSelectedBGColor(float, float, float, float);
	void setFileListSelectedTextColor(float, float, float, float);
	void setTextEntryBorderColor(float, float, float, float);
	void setTextEntryTextColor(float, float, float, float);
	void setTextEntryBackgroundColor(float, float, float, float);
	void setBackgroundColor(float, float, float, float);
	void setBorderColor(float, float, float, float);
	void setButtonBorderColor(float, float, float, float);
	void setButtonNormalBackgroundColor(float, float, float, float);
	void setButtonDepressedBackgroundColor(float, float, float, float);
	void setButtonTextColor(float, float, float, float);
	
	void setNumberOfItemsInList(int);
	virtual void draw();
	virtual void setBounds(int, int);
	virtual void setPos(int, int);
	int poll();
	char *selection();
};

#endif
