////////////////////////////////////////////////////////////////////////////////
// supermissile
////////////////////////////////////////////////////////////////////////////////
//
// File: SMUIListBox.h
//
// Description: Declaration of the SMUIListBox class. This class renders basic
//				scrollable listboxes that can contain any number of items and
//				performs automatic resizing or truncating given the wishes
//				of the caller
//
//				See SMUIListBox.cpp
//
////////////////////////////////////////////////////////////////////////////////
#ifndef SMUILISTBOX_H
#define SMUILISTBOX_H

class SMUIListBox : public _SMUIWidget
{
private:
	std::vector <char *> _items;
	std::vector <char *> _displayItems;
	SMFont *_font;
	void resize();
	void clearItems();
	void clearDisplayItems();
	
	float _br;
	float _bg;
	float _bb;
	float _ba;
	
	float _tr;
	float _tg;
	float _tb;
	float _ta;
	
	float _rb1r;
	float _rb1g;
	float _rb1b;
	float _rb1a;
	
	float _rb2r;
	float _rb2g;
	float _rb2b;
	float _rb2a;
	
	float _sibgr;
	float _sibgg;
	float _sibgb;
	float _sibga;
	
	float _sitr;
	float _sitg;
	float _sitb;
	float _sita;
	
	int _selectedItemIndex;
	int _numberOfDisplayItems;
	int _displayStartIndex;
	
	int _boundsExplicitlySet;
	
public:
	SMUIListBox();
	~SMUIListBox();
	
	void addItem(char *);
	int numberOfItems(void);
	
	// Returns a copy
	char *itemAtIndex(int );
	
	// Destroys the internal version and 
	// returns a copy
	char *popItem();
	
	void poll();
	virtual void setBounds(int, int);
	virtual void draw();
	int setFont(char *, int);
	int setFontSize(int);
	
	void setDisplayStrings();
	void recreateDisplayItems();
	void selectItemAtIndex(int index);
	int selectedItemIndex();
	void clearAllItems(void);
	void setStartItemIndex(int);
	int startItemIndex(void);
	
	int getNumberOfDisplayItems();
	void setNumberOfDisplayItems(int);
	void setBorderColor(float, float, float, float);
	void setTextColor(float, float, float, float);
	void setRowColors(float, float, float, float, float, float, float, float);
	void setSelectedBGColor(float, float, float, float);
	void setSelectedTextColor(float, float, float, float);

};

#endif
