////////////////////////////////////////////////////////////////////////////////
// supermissile
////////////////////////////////////////////////////////////////////////////////
//
// File: SMUITextEntry.h
//
// Description: Declaration of the SMUITextEntry class. This class renders basic
//				text entry widgets that allow the user to select, navigate, and
//				type textual data into
//
//				See SMUITextEntry.cpp
//
////////////////////////////////////////////////////////////////////////////////
#ifndef SMUITEXTENTRY_H
#define SMUITEXTENTRY_H

class SMUITextEntry : public _SMUIWidget
{
private:
	SMFont *_font;
	int _maxLength;
	char *_inputString;
	char *_displayString;
	int _inputIndex;
	int _displayStartIndex;
	int _maxHeight;
	
	// Text color
	float _tr;
	float _tg;
	float _tb;
	float _ta;
	
	// Background color
	float _bgr;
	float _bgg;
	float _bgb;
	float _bga;
	
	// Border color
	float _bdr;
	float _bdg;
	float _bdb;
	float _bda;
	
	// Cursor color
	float _cr;
	float _cg;
	float _cb;
	float _ca;
	
	// Focus color
	float _fr;
	float _fg;
	float _fb;
	float _fa;
	
	SMTimer *_repeatTimer;
	int _preventRepeat;
	int _repeatKey;
	
	SMTimer *_cursorTimer;
	int _drawCursor;
	
	int displayWidth();
	void append(char *);
	void backspace();
	void forwardDelete();
	void resize();
	void calculateDisplayStartToFillField();
	void calculateDisplayString();
	static const char *_alphabet;
	
protected:
public:
	SMUITextEntry();
	SMUITextEntry(int);
	~SMUITextEntry();
	
	virtual void draw();
	virtual void setBounds(int, int);
//	virtual int h();
//	virtual int w();
	
	void forceFocus();
	
	char *getText();
	void setText(char *);
	int setFont(char *, int);
	int setFontSize(int);
	void setBackgroundColor(float r, float g, float b, float a);
	void setBorderColor    (float r, float g, float b, float a);
	void setCursorColor    (float r, float g, float b, float a);
	void setTextColor      (float r, float g, float b, float a);
	void setFocusColor     (float r, float g, float b, float a);
	
	void poll();
};

#endif
