////////////////////////////////////////////////////////////////////////////////
// supermissile
////////////////////////////////////////////////////////////////////////////////
//
// File: SuperMissile.h
//
// Description: Main header file which includes all other hedares
//              pertinent to the supermissile library. Additionally,
//              all global definitions are contained herein, as well
//              as variables that contain states of the overall supermissile
//              status
//
//				See SuperMissile.cpp
//
////////////////////////////////////////////////////////////////////////////////
#ifndef SUPERMISSILE_H
#define SUPERMISSILE_H

#include <SuperMissile/SMTexture.h>
#include <SuperMissile/SMInit.h>
#include <SuperMissile/SMVideoMode.h>
#include <SuperMissile/SMLogicTiming.h>
#include <SuperMissile/SMTimer.h>
#include <SuperMissile/SMFPSTiming.h>
#include <SuperMissile/SMSound.h>
#include <SuperMissile/SMMusic.h>
#include <SuperMissile/SMKeyboard.h>
#include <SuperMissile/SMMouse.h>
#include <SuperMissile/SMGamePad.h>

// Order is important. Cache contains Cache Items. Cache Items hold Fonts
#include <SuperMissile/SMFont.h>          
#include <SuperMissile/SMFontCacheItem.h>
#include <SuperMissile/SMFontCache.h>

#include <SuperMissile/SMFileSystem.h>
#include <SuperMissile/SMPrimitives.h>
#include <SuperMissile/SMUIWidget.h>
#include <SuperMissile/SMUIButton.h>
#include <SuperMissile/SMUIListBox.h>
#include <SuperMissile/SMUITextEntry.h>
#include <SuperMissile/SMUIFileBrowser.h>
#include <SuperMissile/SMUIMenuBase.h>
#include <SuperMissile/SMUIMenuItem.h>
#include <SuperMissile/SMUIMenu.h>
#include <SuperMissile/SMUIDialogBox.h>

#include <SuperMissile/SMVector3D.h>
#include <SuperMissile/SMRandom.h>

#include <SuperMissile/SMNetworkBuffer.h>
#include <SuperMissile/SMNetworkServer.h>
#include <SuperMissile/SMNetworkClient.h>
#include <SuperMissile/SMNetworkUtil.h>

// Useful constants for any function
#define SMNone 0
#define SMTrue -1
#define SMFalse 0

// For fonts and textures
#define SMAliased 1
#define SMAntiAliased 2

// Screen modes
#define SMFullscreen 1
#define SMWindowed 0

// Video modes
#define _SM2D 0
#define _SM3D 1

// For sprite flipping
#define SMHFlip 2
#define SMVFlip 4

// For filesystem
#define SMFile 2
#define SMDirectory 4

// For what endianness we're in
#define _SMLittleEndian SMTrue
#define _SMBigEndian SMFalse

// For the error string
#define _SMErrorSize 512

// Global variables pertaining to
// main status of the library
extern int _SMAppQuitRequested;
extern SDL_Event _SMMainEvent;
extern char *SMExecutablePath;
extern int _SMEndianness;
extern char *_SMError;
extern _SMFontCache *_SMGlobalFontCache;

#ifdef SMMACOSX
extern char *SMBundlePath;
#endif

int SMApplicationQuitRequested(void);
void SMClearGUIFontCache(void);
int SMGUIFontCacheSize();
char *SMError();
void _SMSetError(char *, ...);

#endif

